package com.ruoyi.system.mapper.fgw;

import com.ruoyi.system.domain.fgw.FgwXmsb;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 发改委_申报_主Mapper接口
 * 
 * @author boman
 * @date 2023-03-22
 */
public interface FgwXmsbMapper 
{
    /**
     * 查询发改委_申报_主
     * 
     * @param id 发改委_申报_主主键
     * @return 发改委_申报_主
     */
    public FgwXmsb selectFgwXmsbById(Long id);

    /**
     * 查询发改委_申报_主列表
     * 
     * @param fgwXmsb 发改委_申报_主
     * @return 发改委_申报_主集合
     */
    public List<FgwXmsb> selectFgwXmsbList(FgwXmsb fgwXmsb);
    public List<FgwXmsb> selectFgwXmsbListTj(FgwXmsb fgwXmsb);

    /**
     * 新增发改委_申报_主
     * 
     * @param fgwXmsb 发改委_申报_主
     * @return 结果
     */
    public int insertFgwXmsb(FgwXmsb fgwXmsb);

    /**
     * 修改发改委_申报_主
     * 
     * @param fgwXmsb 发改委_申报_主
     * @return 结果
     */
    public int updateFgwXmsb(FgwXmsb fgwXmsb);

    /**
     * 修改项目进度
     * @param fgwXmsb
     * @return
     */
    public int updateFgwXmsbStatus(FgwXmsb fgwXmsb);

    /**
     * 删除发改委_申报_主
     * 
     * @param id 发改委_申报_主主键
     * @return 结果
     */
    public int deleteFgwXmsbById(Long id);

    /**
     * 批量删除发改委_申报_主
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFgwXmsbByIds(Long[] ids);

    List<FgwXmsb> ldpsList(FgwXmsb fgwXmsb);

    List<FgwXmsb> selectFgwXmsbListAll(FgwXmsb fgwXmsb);

    List<FgwXmsb> selectFgwXmsbByIdList(@Param("idList") List<Long> idList);
}
